Package

Type Alias Package 

pub type Package<M> = Package<BluePallas<M>>;
A package that must be sent by each participant to some other participants in Round 2 of the DKG protocol. Note that there is one specific package for each specific recipient, in contrast to Round 1.

Security

The package must be sent on an confidential and authenticated channel.

Aliased Type

pub struct Package<M> { /* private fields */ }