pub type SecretPackage<M> = SecretPackage<BluePallas<M>>;Expand description
The secret package that must be kept in memory by the participant between the second and third parts of the DKG protocol (round 2).
Security
This package MUST NOT be sent to other participants!
Aliased Type
pub struct SecretPackage<M> { /* private fields */ }